@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -118,7 +118,7 @@ public class TemplateServiceImpl implements TemplateService {
     }
 
     public OXTemplate loadTemplate(String templateName, String defaultTemplateName, ServerSession session) throws TemplateException {
-        if(isEmpty(templateName) || !isUserTemplatingEnabled()) {
+        if(isEmpty(templateName) || !isUserTemplatingEnabled(session)) {
             return loadTemplate(defaultTemplateName);
         }
         try {
@@ -163,8 +163,8 @@ public class TemplateServiceImpl implements TemplateService {
         }
     }
 
-    private boolean isUserTemplatingEnabled() {
-        return "true".equalsIgnoreCase(config.getProperty(USER_TEMPLATING_PROPERTY,"true"));
+    private boolean isUserTemplatingEnabled(ServerSession session) {
+        return "true".equalsIgnoreCase(config.getProperty(USER_TEMPLATING_PROPERTY,"true")) && session.getUserConfiguration().hasInfostore();
     }
 
     private boolean isEmpty(String templateName) {
